@@ -1,6 +1,6 @@
 /* Check out working files from revisions of RCS files.
 
-   Copyright (C) 2010-2013 Thien-Thi Nguyen
+   Copyright (C) 2010-2014 Thien-Thi Nguyen
    Copyright (C) 1990, 1991, 1992, 1993, 1994, 1995 Paul Eggert
    Copyright (C) 1982, 1988, 1989 Walter Tichy
 
@@ -68,7 +68,7 @@ cleanup (int *exitstatus, FILE **neworkptr)
   FILE *mstdout = MANI (standard_output);
 
   if (FLOW (erroneousp))
-    *exitstatus = EXIT_FAILURE;
+    *exitstatus = exit_failure;
   fro_zclose (&FLOW (from));
   ORCSclose ();
   if (FLOW (from)
